==> munipack_0.5.7.orig.tar.gz: munipack-0.5.7/xmunipack/display.h <==
/*

  xmunipack - display's headers

  Copyright © 2012-13 F.Hroch (hroch@physics.muni.cz)

  This file is part of Munipack.

  Munipack is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.
  
  Munipack is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with Munipack.  If not, see <http://www.gnu.org/licenses/>.

*/

#ifndef _MUNI_PLOT_H_
#include "plot.h"
#endif

#ifndef _FITS_H_
#include "fits.h"
#endif

#ifndef _XMUNIPACK_ENUM_H_
#include "enum.h"
#endif

#ifndef _XMUNIPACK_EVENT_H_
#include "event.h"
#endif

#ifndef _XMUNIPACK_CONFIG_H_
#include "mconfig.h"
#endif

#ifndef _XMUNIPACK_TYPES_H_
#include "types.h"
#endif

#include <wx/wx.h>
#include <list>


class MuniCanvasMini: public wxWindow
{
public:
  MuniCanvasMini(wxWindow *, int, int);
  void SetImage(const wxBitmap&);
  wxSize DoGetBestSize() const;

private:

  int size,scale;
  wxBitmap image;

  void OnPaint(wxPaintEvent&);
  void OnUpdate(wxUpdateUIEvent&);
  
};


class MuniDetail: public wxDialog
{
public:
  MuniDetail(wxWindow *, wxWindowID, const wxPoint&, const wxSize&, 
	     MuniConfig *);

  void Assign(const FitsCoo&, const FitsValue&);

private:

  MuniConfig *config;
  FitsCoo coords;
  FitsValue values;

  MuniCanvasMini *zoom;
  wxChoice *coochoice, *valchoice;
  wxString values_str,xcoo_str,ycoo_str;

  void OnMouseMotion(MuniSlewEvent&);
  void OnChoiceCoo(wxCommandEvent&);
  void OnChoiceVal(wxCommandEvent&);
  void OnClose(wxCloseEvent&);
  void OnUpdateValue(wxUpdateUIEvent&);
  void OnUpdateXCoo(wxUpdateUIEvent&);
  void OnUpdateYCoo(wxUpdateUIEvent&);
  void OnUpdateXlabel(wxUpdateUIEvent&);
  void OnUpdateYlabel(wxUpdateUIEvent&);

};


class MuniDisplayPanel: public wxScrolledWindow
{
public:
  MuniDisplayPanel(wxWindow *w, MuniConfig *c);

  void SetHdu(const FitsArray&, const FitsHisto&);
  
private:

  MuniConfig *config;
  FitsValue value;
  FitsCoo coords;
  FitsArray hdu;
  wxString val_str,val_label,fxcoo_str,fycoo_str,xcoo_str,ycoo_str,tobject,
    tdate,ttime,texp,tband,tsize;
  MuniCanvasMini *zoom;
  wxTextCtrl *val,*xcoo,*ycoo,*acoo,*dcoo;
  wxButton *ctype;
  wxStaticText *value_label;
  MuniPlotHisto *phisto;
  std::list<long> ids;
  std::list<wxString> labels;

  void OnPopVal(wxCommandEvent&);
  void OnPopCoo(wxCommandEvent&);
  void OnCooUnit(wxCommandEvent&);
  void OnValUnit(wxCommandEvent&);
  void OnMouseMotion(MuniSlewEvent&);
  void OnUpdateValue(wxUpdateUIEvent&);
  void OnUpdateXCoo(wxUpdateUIEvent&);
  void OnUpdateYCoo(wxUpdateUIEvent&);
  void OnUpdateACoo(wxUpdateUIEvent&);
  void OnUpdateDCoo(wxUpdateUIEvent&);
  void SetValueLabel(int);

  /*
  void OnUpdateObject(wxUpdateUIEvent&);
  void OnUpdateDate(wxUpdateUIEvent&);
  void OnUpdateTime(wxUpdateUIEvent&);
  void OnUpdateExp(wxUpdateUIEvent&);
  void OnUpdateBand(wxUpdateUIEvent&);
  void OnUpdateSize(wxUpdateUIEvent&);
  */
};


class ImageRender: public wxThread
{
public:
  ImageRender(wxEvtHandler *, const FitsImage&, const FitsImage&, 
	      const FitsDisplay&, double, bool, int, int, int, int);
  virtual ~ImageRender();

private:
  
  wxEvtHandler *handler;
  FitsImage fitsimage,fimage;
  FitsDisplay display;
  double zoom;
  bool zooming;
  int x0,y0,width,height;

  ExitCode Entry();
};


class MuniDisplayCanvas: public wxScrolledCanvas
{
public:
  MuniDisplayCanvas(wxWindow *w, MuniConfig *c);
  virtual ~MuniDisplayCanvas();
  
  wxSize DoGetBestSize() const { return wxSize(162,100); }
  void SetHandler(wxEvtHandler *);
  void SetHdu(const FitsArray&, const wxImage&, const FitsArrayStat&);
  void Render();
  void StopRendering();
  bool IsRendering() const { return render; }
  double GetFitZoom() const;
  double GetZoom() const { return zoom; }
  FitsItt GetItt() const { return itt; };
  FitsPalette GetPalette() const { return pal; }
  FitsColor GetColor() const { return color; }
  wxImage GetImage() { return canvas; }
  bool GetFit() const { return fit; }

  void OnTuneFine(MuniTuneEvent&);
  void OnAstrometry(MuniAstrometryEvent&);
  void OnPhotometry(MuniPhotometryEvent&);
  void OnConfigUpdated(wxCommandEvent&);
  //  void AddOverlay(const vector<MuniDrawBase *>& o) { /*drawobj = o;*/ OverlayBitmap(o); Refresh();}
  //  void ShowGrid(const vector<wxGraphicsPath>& ps) { OverlayGrid(ps); Refresh();}
  void AddLayer(const MuniLayer&);
  void RemoveLayers(int);

  // protected:

  wxCriticalSection renderCS;
  ImageRender *render;

private:

  wxWindow *topwin;
  MuniConfig *config;
  wxMemoryDC memdc;
  std::vector<wxBitmap> overlay;
  wxEvtHandler *handler;

  FitsArray hdu;
  wxImage icon, canvas;
  int xoff,yoff,xdrag0,ydrag0,vbX,vbY;
  FitsImage fitsimage, fimage;
  FitsDisplay display;
  FitsBitmap picture;
  FitsPalette pal;
  FitsItt itt, itt_orig;
  FitsColor color;
  double zoom, zoomfit;
  bool zooming;
  bool dragging,rendering;
  bool stick,fit,astrometry;
  double xcen, ycen, acen, dcen, ascale, aangle;
  //  vector<MuniDrawBase *> drawobj;
  //  std::vector<wxXmlDocument> layers;
  std::list<MuniLayer> layers;

  void OnClose(wxCloseEvent&);
  void OnSize(wxSizeEvent&);
  void OnPaint(wxPaintEvent&);
  void OnErase(wxEraseEvent&);
  void OnScroll(wxScrollWinEvent&);
  void OnMouseMotion(wxMouseEvent&);
  void OnMouseWheel(wxMouseEvent&);
  void OnLeftUp(wxMouseEvent&);
  void OnRenderFinish(MuniRenderEvent&);
  void OnSubRender(MuniRenderEvent&);
  void InitDC(int,int,double);
  void Reset();
  //  void OverlayBitmap(const vector<MuniDrawBase *>&);
  //  void OverlayGrid(const vector<wxGraphicsPath>&);
  void SetInitZoom(double =-1.0);
  void OnStick(wxCommandEvent&);
  void OnKeyDown(wxKeyEvent&);
  void OnMenu(wxMouseEvent& WXUNUSED(event));
  void OnIdle(wxIdleEvent&);
  void InitITT(const FitsArray&, const FitsArrayStat&);
  //  void DrawSVG(wxPaintDC&, const wxXmlDocument&);
  void DrawLayer(wxPaintDC&, const MuniLayer&);
  void ConvertCoo(double,double,double&,double&);

};

==> munipack_0.5.11.orig.tar.gz: munipack-0.5.11/xmunipack/display.h <==
/*

  xmunipack - display's headers

  Copyright © 2012-13, 2018 F.Hroch (hroch@physics.muni.cz)

  This file is part of Munipack.

  Munipack is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  Munipack is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with Munipack.  If not, see <http://www.gnu.org/licenses/>.

*/

#ifndef _MUNI_PLOT_H_
#include "plot.h"
#endif

#ifndef _FITS_H_
#include "fits.h"
#endif

#ifndef _XMUNIPACK_ENUM_H_
#include "enum.h"
#endif

#ifndef _XMUNIPACK_EVENT_H_
#include "event.h"
#endif

#ifndef _XMUNIPACK_CONFIG_H_
#include "mconfig.h"
#endif

#ifndef _XMUNIPACK_TYPES_H_
#include "types.h"
#endif

#include <wx/wx.h>
#include <wx/html/htmlwin.h>
#include <list>


class MuniCanvasMini: public wxWindow
{
public:
  MuniCanvasMini(wxWindow *, int, int);
  wxSize DoGetBestSize() const;
  void SetArray(const FitsArray&);

private:

  int size,scale;
  wxBitmap canvas;
  FitsImage image;
  FitsTone tone;
  FitsItt itt;
  FitsPalette pal;
  FitsColor colour;
  wxPoint crosshair;

  void OnPaint(wxPaintEvent&);
  void OnUpdate(wxUpdateUIEvent&);
  void OnMouseMotion(MuniSlewEvent&);
  void OnFullTune(MuniFullTuneEvent&);
  void Render(const wxPoint&);

};


// OBSOLETE ???????
class MuniDetail: public wxDialog
{
public:
  MuniDetail(wxWindow *, wxWindowID, const wxPoint&, const wxSize&,
	     MuniConfig *);

  void Assign(const FitsCoo&, const FitsValue&);

private:

  MuniConfig *config;
  FitsCoo coords;
  FitsValue values;

  MuniCanvasMini *zoom;
  wxChoice *coochoice, *valchoice;
  wxString values_str,xcoo_str,ycoo_str;

  void OnMouseMotion(MuniSlewEvent&);
  void OnChoiceCoo(wxCommandEvent&);
  void OnChoiceVal(wxCommandEvent&);
  void OnClose(wxCloseEvent&);
  void OnUpdateValue(wxUpdateUIEvent&);
  void OnUpdateXCoo(wxUpdateUIEvent&);
  void OnUpdateYCoo(wxUpdateUIEvent&);
  void OnUpdateXlabel(wxUpdateUIEvent&);
  void OnUpdateYlabel(wxUpdateUIEvent&);

};


class MuniDisplayPanel: public wxScrolledWindow
{
public:
  MuniDisplayPanel(wxWindow *w, MuniConfig *c);

  void SetArray(const FitsArray&);
  void OnFullTune(MuniFullTuneEvent&);

private:

  MuniConfig *config;
  FitsValue value;
  FitsCoo coords;
  FitsArray array;
  bool hist_init, mini_init;
  wxString val_label, xval_str,yval_str,zval_str,
    acoo_str,dcoo_str,xcoo_str,ycoo_str;
  MuniCanvasMini *zoom;
  wxStaticText *xval,*yval,*zval,*xcoo,*ycoo,*acoo,*dcoo,
    *label_alpha, *label_delta, *label_x, *label_y;
  wxFlexGridSizer *xgrid;
  wxButton *valtype,*ctype;
  wxStaticText *value_label;
  MuniPlotHisto *phisto;
  wxHtmlWindow *html;
  std::list<long> ids;
  std::list<wxString> labels;

  void OnIdle(wxIdleEvent&);
  void OnPopVal(wxCommandEvent&);
  void OnPopCoo(wxCommandEvent&);
  void OnCooUnit(wxCommandEvent&);
  void OnValUnit(wxCommandEvent&);
  void OnMouseMotion(MuniSlewEvent&);
  void OnUpdateXValue(wxUpdateUIEvent&);
  void OnUpdateYValue(wxUpdateUIEvent&);
  void OnUpdateZValue(wxUpdateUIEvent&);
  void OnUpdateXCoo(wxUpdateUIEvent&);
  void OnUpdateYCoo(wxUpdateUIEvent&);
  void OnUpdateACoo(wxUpdateUIEvent&);
  void OnUpdateDCoo(wxUpdateUIEvent&);
  void SetValueLabel(int);
  void UpdateCooPanel(int);
};


class DisplayShrinkRender: public wxThread
{
  wxEvtHandler *handler;
  FitsImage image;
  FitsTone tone;
  int shrink;
  int thisid;
  ExitCode Entry();

 public:
  DisplayShrinkRender(wxEvtHandler *, const FitsImage&, const FitsTone&,
		      int, int);
  virtual ~DisplayShrinkRender();
};


class DisplayTuneRender: public wxThread
{
  wxEvtHandler *handler;
  FitsImage image;
  FitsTone tone;
  FitsItt itt;
  FitsPalette pal;
  FitsColor colour;
  int thisid;
  ExitCode Entry();

 public:
  DisplayTuneRender(wxEvtHandler *, const FitsImage&, const FitsTone&,
		    const FitsItt&, const FitsPalette&, const FitsColor&, int);
  virtual ~DisplayTuneRender();
};


class MuniDisplayCanvas: public wxScrolledCanvas
{
public:
  MuniDisplayCanvas(wxWindow *w, MuniConfig *c);
  virtual ~MuniDisplayCanvas();

  void SetHandler(wxEvtHandler *);
  void SetHdu(const FitsArray&, const wxImage&, bool);
  void StopRendering();
  FitsZoom GetZoom() const;
  FitsTone GetTone() const { return tone; };
  FitsItt GetItt() const { return itt; };
  FitsPalette GetPalette() const { return pal; }
  FitsColor GetColor() const { return color; }
  wxImage GetImage() { return canvas; }
  int GetFitShrink() const;

  void OnTuneFine(MuniTuneEvent&);
  void OnMenuPalauto(wxCommandEvent&);
  void OnValueType(wxCommandEvent&);
  void OnCooType(wxCommandEvent&);
  void OnAstrometry(MuniAstrometryEvent&);
  void OnPhotometry(MuniPhotometryEvent&);
  void AddLayer(const MuniLayer&);
  void RemoveLayers(int);

private:

  friend class DisplayShrinkRender;
  friend class DisplayTuneRender;
  wxCriticalSection renderCS;
  wxThread *render;
  int canvasid;


  wxWindow *topwin;
  MuniConfig *config;
  wxEvtHandler *handler;

  FitsArray array;
  wxImage icon, canvas;
  int xoff,yoff,xdrag0,ydrag0,vbX,vbY;
  FitsImage fitsimage, scaled;
  FitsPalette pal;
  FitsTone tone;
  FitsItt itt;
  FitsColor color;
  int value_type, coo_type;
  int scaleicon;
  int shrink, zoom;
  bool palauto, zooming, update_zoom, shrinking, tunning, completed;
  bool dragging,rendering;
  bool astrometry;
  double xcen, ycen, acen, dcen, ascale, aangle;
  wxPoint crosshair;
  std::list<MuniLayer> layers;

  void OnClose(wxCloseEvent&);
  void OnSize(wxSizeEvent&);
  void OnPaint(wxPaintEvent&);
  void OnMouseMotion(wxMouseEvent&);
  void OnMouseWheel(wxMouseEvent&);
  void OnLeftUp(wxMouseEvent&);
  void OnRenderFinish(MuniRenderEvent&);
  void OnSubRender(MuniRenderEvent&);
  void Reset();
  //  void OverlayBitmap(const vector<MuniDrawBase *>&);
  //  void OverlayGrid(const vector<wxGraphicsPath>&);
  void OnClipValue(wxCommandEvent&);
  void OnClipCoo(wxCommandEvent&);
  void OnKeyDown(wxKeyEvent&);
  void OnMenu(wxMouseEvent& event);
  void OnIdle(wxIdleEvent&);
  //  void DrawSVG(wxPaintDC&, const wxXmlDocument&);
  void DrawLayer(wxPaintDC&, const MuniLayer&);
  void ConvertCoo(double,double,double&,double&);
  wxPoint GetCartesianPosition(const wxPoint&) const;

  void InitCanvas();
  void UpdateCanvas(int,int);
  void UpdateCanvas();
  void UpdateTune();
  void UpdateScale(bool, int);
  void UpdateScale();
  void UpdateScroll();
  void StartRendering();
  void SelectAutoPal();

};
